//
// Copyright (c) 1997, Jason Marshall.  All Rights Reserved
//
// The author makes no representations or warranties regarding the suitability,
// reliability or stability of this code.  This code is provided AS IS.  The
// author shall not be liable for any damages suffered as a result of using,
// modifying or redistributing this software or any derivitives thereof.
// Permission to use, reproduce, modify and/or (re)distribute this software is
// hereby granted.

//  ImageWindow  A window to display an Image in, for test purposes.
//  Jason Marshall

import java.awt.*;
import java.awt.image.*;
import java.io.*;
import java.util.*;

class ImageWindow extends Frame {
    Image theImage = null;
    ImagePanel panel;

    public ImageWindow(String s) {
    	super(s);
    	ScrollPane pane = new ScrollPane();
    	panel = new ImagePanel();
    	add(pane);
    	pane.add(panel);
    	pane.show();
        setSize(new Dimension(400, 300));
	}

    public Dimension getPreferredSize() {
        return panel.preferredSize();
    }

    public static void main(String args[]) {
        String image;
        if (args.length == 0) {
/*
                ImageWindow theWindow = new ImageWindow(image);
                try {
                    theWindow.ShowFileImage(image);
                } catch (java.io.IOException exception) {
                    System.exit(1);
                }
                try {
                    Thread.sleep(15000);
                } catch (InterruptedException ie) {}
                theWindow.hide();
                theWindow.dispose();
            }
*/
        } else {
            image = args[0];
            ImageWindow theWindow = new ImageWindow(image);
            try {
                theWindow.ShowFileImage(image);
            } catch (java.io.IOException exception) {
                System.exit(1);
            }
        }
    }

    public void ShowFileImage(String s) throws IOException {
        show();
        panel.ShowFileImage(s);
        repaint();
        validateTree();
    }

    public boolean handleEvent(Event evt) {
    	if (evt.id == Event.WINDOW_DESTROY) {
            System.exit(0);
        }
    	return false;
	}
}

class ImagePanel extends Panel {
    Dimension preferredSize = new Dimension(400, 300);
    boolean sized = false;
    Image theImage = null;

    public Dimension getPreferredSize() {
        return preferredSize;
    }

    public void ShowFileImage(String s) throws IOException {
        show();
        ImageProducer ip = new PNGImageProducer(new FileInputStream(s));
	    theImage = createImage(ip);
        repaint();
	}

    public boolean imageUpdate(java.awt.Image img, int flags,
                                    int x, int y, int w, int h) {
        if ((flags & (SOMEBITS|FRAMEBITS|ALLBITS)) != 0) {
            if (!sized) {
                int imageWidth = theImage.getWidth(this);
                int imageHeight = theImage.getHeight(this);
                preferredSize = new Dimension(imageWidth, imageHeight);
                setSize(preferredSize);
                invalidate();
                sized = true;
            }
            repaint(x, y - 1, w, h + 1);
        }
        return (flags & (ALLBITS|ERROR)) == 0;
    }

    public void paint(Graphics g) {
        if (theImage != null) {
            g.drawImage(theImage, 0, 0, this);
        }
    }

    public void update(Graphics g) {
    	paint(g);
	}
}
